% Auto-generated chapter 22 for tirmidhi
% Hadiths in this chapter: 51

\hadithdefcmd{tirmidhi}{1619}{حَدَّثَنَا قُتَيْبَةُ بْنُ سَعِيدٍ، حَدَّثَنَا أَبُو عَوَانَةَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قِيلَ يَا رَسُولَ اللَّهِ مَا يَعْدِلُ الْجِهَادَ قَالَ ‏"‏ لاَ تَسْتَطِيعُونَهُ ‏"‏ ‏.‏ فَرَدُّوا عَلَيْهِ مَرَّتَيْنِ أَوْ ثَلاَثًا كُلُّ ذَلِكَ يَقُولُ ‏"‏ لاَ تَسْتَطِيعُونَهُ ‏"‏ ‏.‏ فَقَالَ فِي الثَّالِثَةِ ‏"‏ مَثَلُ الْمُجَاهِدِ فِي سَبِيلِ اللَّهِ مَثَلُ الْقَائِمِ الصَّائِمِ الَّذِي لاَ يَفْتُرُ مِنْ صَلاَةٍ وَلاَ صِيَامٍ حَتَّى يَرْجِعَ الْمُجَاهِدُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنِ الشَّفَاءِ وَعَبْدِ اللَّهِ بْنِ حُبْشِيٍّ وَأَبِي مُوسَى وَأَبِي سَعِيدٍ وَأُمِّ مَالِكٍ الْبَهْزِيَّةِ وَأَنَسِ بْنِ مَالِكٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1619}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Hurairah: "It was said, 'O Messenger of Allah, what equals Jihad?' He said: 'Verily, you (people) are not capable of it.' So they repeated it to him two or three times, each time he said, 'You (people) are not capable of it.' Then he said the third time: 'The example of the Mujahid in the path of Allah is like the one who fasts and stands (in prayer) and does not slacken from Salat, nor fasting, until the Mujahid in the cause of Allah returns.'" There are narrations on this topic from Ash-Shifa', 'Abdullah bin Hubshi, Abu Musa', Abu Sa'eed, Umm Malik Al-Bahziyyah, and Anas. This Hadith is a Hasan Sahih. And it has been reported through more than one route from Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1620}{حَدَّثَنَا مُحَمَّدُ بْنُ عَبْدِ اللَّهِ بْنِ بَزِيعٍ، حَدَّثَنَا الْمُعْتَمِرُ بْنُ سُلَيْمَانَ، حَدَّثَنِي مَرْزُوقٌ أَبُو بَكْرٍ، عَنْ قَتَادَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَعْنِي ‏ "‏ يَقُولُ اللَّهُ عَزَّ وَجَلَّ الْمُجَاهِدُ فِي سَبِيلِ اللَّهِ هُوَ عَلَىَّ ضَامِنٌ إِنْ قَبَضْتُهُ أَوْرَثْتُهُ الْجَنَّةَ وَإِنْ رَجَعْتُهُ رَجَعْتُهُ بِأَجْرٍ أَوْ غَنِيمَةٍ ‏"‏ ‏.‏ قَالَ هُوَ صَحِيحٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏\hadithno{1620}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Anas bin Malik: "The Messenger of Allah (ﷺ) said: meaning: Allah Mighty and Sublime is He says: 'The Mujahid in My cause, he has guarantee fro Me. If I I seize him, I cause him to inherit Paradise, and if I return him, I return him with a reward or spoils of war.'" [He said:] This Hadith is Gharib Sahih from this route}}
\hadithdefcmd{tirmidhi}{1621}{حَدَّثَنَا أَحْمَدُ بْنُ مُحَمَّدٍ، أَخْبَرَنَا عَبْدُ اللَّهِ بْنُ الْمُبَارَكِ، أَخْبَرَنَا حَيْوَةُ بْنُ شُرَيْحٍ، قَالَ أَخْبَرَنِي أَبُو هَانِئٍ الْخَوْلاَنِيُّ، أَنَّ عَمْرَو بْنَ مَالِكٍ الْجَنْبِيَّ، أَخْبَرَهُ أَنَّهُ، سَمِعَ فَضَالَةَ بْنَ عُبَيْدٍ، يُحَدِّثُ عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ كُلُّ مَيِّتٍ يُخْتَمُ عَلَى عَمَلِهِ إِلاَّ الَّذِي مَاتَ مُرَابِطًا فِي سَبِيلِ اللَّهِ فَإِنَّهُ يُنْمَى لَهُ عَمَلُهُ إِلَى يَوْمِ الْقِيَامَةِ وَيَأْمَنُ مِنْ فِتْنَةِ الْقَبْرِ ‏"‏ ‏.‏ وَسَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الْمُجَاهِدُ مَنْ جَاهَدَ نَفْسَهُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُقْبَةَ بْنِ عَامِرٍ وَجَابِرٍ ‏.‏ وَحَدِيثُ فَضَالَةَ بْنِ عُبَيْدٍ حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1621}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Fadalah bin 'Ubaid: That the Messenger of Allah (ﷺ) said: "The deeds of everyone who dies are sealed. Except for the one who dies guarding the frontier from the enemy, in the cause of Allah. For indeed his actions are increased for him until the Day of Judgement, and he is secure from the tribulation of the grave." And I heard the Messenger of Allah (ﷺ) saying: "The Mujahid is one who strives against his own soul." [Abu 'Eisa said:] There are narrations on this topic from 'Uqbah bin 'Amir and Jabir. The Hadith is Fadalah is a Hasan Sahih Hadith}}
\hadithdefcmd{tirmidhi}{1622}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ أَبِي الأَسْوَدِ، عَنْ عُرْوَةَ بْنِ الزُّبَيْرِ، وَسُلَيْمَانَ بْنِ يَسَارٍ، أَنَّهُمَا حَدَّثَاهُ عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ زَحْزَحَهُ اللَّهُ عَنِ النَّارِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏ أَحَدُهُمَا يَقُولُ سَبْعِينَ وَالآخَرُ يَقُولُ أَرْبَعِينَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ ‏.‏ وَأَبُو الأَسْوَدِ اسْمُهُ مُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ بْنِ نَوْفَلٍ الأَسَدِيُّ الْمَدَنِيُّ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي سَعِيدٍ وَأَنَسٍ وَعُقْبَةَ بْنِ عَامِرٍ وَأَبِي أُمَامَةَ ‏.‏\hadithno{1622}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Abu Al-Aswad : From 'Urwah [bin Az-Zubair], and Sulaiman bin Yasar, that they reported to him from Abu Hurairah that the Prophet (ﷺ) said: "Whoever fasts a day in the cause of Allah, Allah shall distance him from the Fire by seventy autumns." One of them said "seventy" and the other said: "forty". [Abu 'Eisa said:] This Hadith is a Gharib Hadith from this route. Abu Al-Aswad's name is Muhammad bin 'Abdur-Rahman bin Nawfal Al-Asadi Al-Madani. There are narrations on this topic from Abu Sa'eed, Anas, 'Uqbah bin 'Amir, and Abu Umamah}}
\hadithdefcmd{tirmidhi}{1623}{حَدَّثَنَا سَعِيدُ بْنُ عَبْدِ الرَّحْمَنِ الْمَخْزُومِيُّ، حَدَّثَنَا عَبْدُ اللَّهِ بْنُ الْوَلِيدِ الْعَدَنِيُّ، حَدَّثَنَا سُفْيَانُ الثَّوْرِيُّ، قَالَ وَحَدَّثَنَا مَحْمُودُ بْنُ غَيْلاَنَ، حَدَّثَنَا عُبَيْدُ اللَّهِ بْنُ مُوسَى، عَنْ سُفْيَانَ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنِ النُّعْمَانِ بْنِ أَبِي عَيَّاشٍ الزُّرَقِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَصُومُ عَبْدٌ يَوْمًا فِي سَبِيلِ اللَّهِ إِلاَّ بَاعَدَ ذَلِكَ الْيَوْمُ النَّارَ عَنْ وَجْهِهِ سَبْعِينَ خَرِيفًا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1623}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Sa’id Al Khudri : That the Prophet (ﷺ) said: "A worshipper does not fast a day in the cause of Allah except that, that day (of fasting) distances the Fire from his face by seventy autumns." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1624}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الْوَلِيدُ بْنُ جَمِيلٍ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ الْبَاهِلِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ صَامَ يَوْمًا فِي سَبِيلِ اللَّهِ جَعَلَ اللَّهُ بَيْنَهُ وَبَيْنَ النَّارِ خَنْدَقًا كَمَا بَيْنَ السَّمَاءِ وَالأَرْضِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ أَبِي أُمَامَةَ ‏.‏\hadithno{1624}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Umamah Al-Bahili: That the Prophet (ﷺ) said, "Whoever fasts a day in the cause of Allah, Allah shall put between him and the Fire a trench whose distance is like that between the heavens and the earth." This Hadith is Gharib as a narration of Abu Umamah}}
\hadithdefcmd{tirmidhi}{1625}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا الْحُسَيْنُ بْنُ عَلِيٍّ الْجُعْفِيُّ، عَنْ زَائِدَةَ، عَنِ الرُّكَيْنِ بْنِ الرَّبِيعِ، عَنْ أَبِيهِ، عَنْ يُسَيْرِ بْنِ عَمِيلَةَ، عَنْ خُرَيْمِ بْنِ فَاتِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ أَنْفَقَ نَفَقَةً فِي سَبِيلِ اللَّهِ كُتِبَتْ لَهُ بِسَبْعِمِائَةِ ضِعْفٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ إِنَّمَا نَعْرِفُهُ مِنْ حَدِيثِ الرُّكَيْنِ بْنِ الرَّبِيعِ ‏.‏\hadithno{1625}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Khuraim bin Fatik: That the Messenger of Allah (ﷺ) said: "Whoever spends a sum in the cause of Allah, it is recorded for him seven-hundred fold." [Abu 'Eisa said:] There are something on this topic from Abu Hurairah. This Hadith is Hasan, we only know of it from the narration of Ar-Rukain bin Ar-Rabi' (a narrator in the chain of this Hadith)}}
\hadithdefcmd{tirmidhi}{1626}{حَدَّثَنَا مُحَمَّدُ بْنُ رَافِعٍ، حَدَّثَنَا زَيْدُ بْنُ حُبَابٍ، حَدَّثَنَا مُعَاوِيَةُ بْنُ صَالِحٍ، عَنْ كَثِيرِ بْنِ الْحَارِثِ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ عَدِيِّ بْنِ حَاتِمٍ الطَّائِيِّ، أَنَّهُ سَأَلَ رَسُولَ اللَّهِ صلى الله عليه وسلم أَىُّ الصَّدَقَةِ أَفْضَلُ قَالَ ‏ "‏ خِدْمَةُ عَبْدٍ فِي سَبِيلِ اللَّهِ أَوْ ظِلُّ فُسْطَاطٍ أَوْ طَرُوقَةُ فَحْلٍ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَقَدْ رُوِيَ عَنْ مُعَاوِيَةَ بْنِ صَالِحٍ هَذَا الْحَدِيثُ مُرْسَلاً وَخُولِفَ زَيْدٌ فِي بَعْضِ إِسْنَادِهِ ‏.‏ قَالَ وَرَوَى الْوَلِيدُ بْنُ جَمِيلٍ هَذَا الْحَدِيثَ عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ عَنْ أَبِي أُمَامَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1626}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated 'Adi bin Hatim At-Tai: That he asked the Messenger of Allah (ﷺ), "Which charity is most virtuous?" He said, "The service of a worshipper in the cause of Allah, or providing the shade of tent, or mount in the cause of Allah." [Abu 'Eisa said:] This Hadith has been reported from Mu'awiyah bin Salih in Mursal form.And Zaid has been contradicted concerning part of its chain. He said: And Al-Walim bin Jamil has reported this Hadith from Al-Qasim Abu 'Abdur-Rahman, from Abu Umamah, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1627}{حَدَّثَنَا بِذَلِكَ، زِيَادُ بْنُ أَيُّوبَ حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَخْبَرَنَا الْوَلِيدُ بْنُ جَمِيلٍ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ أَفْضَلُ الصَّدَقَاتِ ظِلُّ فُسْطَاطٍ فِي سَبِيلِ اللَّهِ وَمَنِيحَةُ خَادِمٍ فِي سَبِيلِ اللَّهِ أَوْ طَرُوقَةُ فَحْلٍ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ وَهُوَ أَصَحُّ عِنْدِي مِنْ حَدِيثِ مُعَاوِيَةَ بْنِ صَالِحٍ ‏.‏\hadithno{1627}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Umamah: That the Messenger of Allah (ﷺ) said: "The most virtuous of charitable spending is the shade of a tent in the cause of Allah, or giving a servant in the cause of Allah, or a riding camel in the cause of Allah." [Abu 'Eisa said:] This Hadith is Hasan Gharib Sahih, and it is more correct to me than the narration of Mu'awiyah bin Salih}}
\hadithdefcmd{tirmidhi}{1628}{حَدَّثَنَا أَبُو زَكَرِيَّا، يَحْيَى بْنُ دُرُسْتَ الْبَصْرِيُّ حَدَّثَنَا أَبُو إِسْمَاعِيلَ، حَدَّثَنَا يَحْيَى بْنُ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ فَقَدْ غَزَا وَمَنْ خَلَفَ غَازِيًا فِي أَهْلِهِ فَقَدْ غَزَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ هَذَا الْوَجْهِ ‏.‏\hadithno{1628}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani: That the Messenger of Allah (ﷺ) said, "Whoever prepares a fighter in Allah's cause, he has participated in a military expedition, and whoever looks after the family of a fighter, he has participated in a military expedition." [Abu 'Eisa said:] This Hadith is Hasan Sahih, and it has been reported through more than one route}}
\hadithdefcmd{tirmidhi}{1629}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنِ ابْنِ أَبِي لَيْلَى، عَنْ عَطَاءٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ أَوْ خَلَفَهُ فِي أَهْلِهِ فَقَدْ غَزَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1629}\hadithgrade{Ahmad Muhammad Shakir: Sahih Lighairihi; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani: That the Messenger of Allah (ﷺ) said, "Whoever prepares a fighter in Allah's cause, or looks after the family of a fighter, then he has participated in a military expedition." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1630}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا يَحْيَى بْنُ سَعِيدٍ، حَدَّثَنَا عَبْدُ الْمَلِكِ بْنُ أَبِي سُلَيْمَانَ، عَنْ عَطَاءٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1630}\hadithgrade{Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani: That the Prophet (ﷺ) said similarly}}
\hadithdefcmd{tirmidhi}{1631}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ، حَدَّثَنَا حَرْبُ بْنُ شَدَّادٍ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ أَبِي سَلَمَةَ، عَنْ بُسْرِ بْنِ سَعِيدٍ، عَنْ زَيْدِ بْنِ خَالِدٍ الْجُهَنِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ جَهَّزَ غَازِيًا فِي سَبِيلِ اللَّهِ فَقَدْ غَزَا وَمَنْ خَلَفَ غَازِيًا فِي أَهْلِهِ فَقَدْ غَزَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1631}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Zaid bin Khalid Al-Juhani: That the Messenger of Allah (ﷺ) said, "Whoever prepares a fighter in Allah's cause, he has participated in a military expedition, and whoever watches after the family of a fighter, he has participated in a military expedition." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1632}{حَدَّثَنَا أَبُو عَمَّارٍ الْحُسَيْنُ بْنُ حُرَيْثٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ يَزِيدَ بْنِ أَبِي مَرْيَمَ، قَالَ لَحِقَنِي عَبَايَةُ بْنُ رِفَاعَةَ بْنِ رَافِعٍ وَأَنَا مَاشٍ، إِلَى الْجُمُعَةِ فَقَالَ أَبْشِرْ فَإِنَّ خُطَاكَ هَذِهِ فِي سَبِيلِ اللَّهِ سَمِعْتُ أَبَا عَبْسٍ يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنِ اغْبَرَّتْ قَدَمَاهُ فِي سَبِيلِ اللَّهِ فَهُمَا حَرَامٌ عَلَى النَّارِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ صَحِيحٌ ‏.‏ وَأَبُو عَبْسٍ اسْمُهُ عَبْدُ الرَّحْمَنِ بْنُ جَبْرٍ ‏.‏ وَفِي الْبَابِ عَنْ أَبِي بَكْرٍ وَرَجُلٍ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ قَالَ أَبُو عِيسَى يَزِيدُ بْنُ أَبِي مَرْيَمَ هُوَ رَجُلٌ شَامِيٌّ رَوَى عَنْهُ الْوَلِيدُ بْنُ مُسْلِمٍ وَيَحْيَى بْنُ حَمْزَةَ وَغَيْرُ وَاحِدٍ مِنْ أَهْلِ الشَّامِ وَبُرَيْدُ بْنُ أَبِي مَرْيَمَ كُوفِيٌّ أَبُوهُ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم وَاسْمُهُ مَالِكُ بْنُ رَبِيعَةَ وَبُرَيْدُ بْنُ أَبِي مَرْيَمَ سَمِعَ مِنْ أَنَسِ بْنِ مَالِكٍ وَرَوَى عَنْ بُرَيْدِ بْنِ أَبِي مَرْيَمَ أَبُو إِسْحَاقَ الْهَمْدَانِيُّ وَعَطَاءُ بْنُ السَّائِبِ وَيُونُسُ بْنُ أَبِي إِسْحَاقَ وَشُعْبَةُ أَحَادِيثَ ‏.‏\hadithno{1632}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih Bukhari}\hadithtrans{Narrated Yazid bin Abu Maryam: "Abayah bin Rifa'ah bin Rafi' met me while I was walking to the Friday prayer. He said: 'Have glad tidings, for indeed these footsteps of yours are in the cause of Allah. I heard Abu 'Abs say: "The Messenger of Allah (ﷺ) said, 'Whoever get his two feet dusty in the path of Allah, then they are prohibited for the Fire.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. Abu 'Abs's name is 'Abdur-Rahman bin Jabr. There are narrations on this topic from Abu Bkar and a man from the Companions of the Prophet (ﷺ). He said: Yazid bin Abi Maryam is a man from Ash-Sham. Al-Walid bin Muslim, Yahya bin Hamzah, and some others among the people of Ash-Sham report from him. Buraid bin Abi Maryam is form Al-Kufah. His father is one of the Companions of the Prophet (ﷺ) whose name was Malik bin Rabi'ah. [Buraid bin Abi Maryam heard from Anas bin Malik. Abu Ishaq Al-Hamdani, 'Ata bin As-Sa'ib, Yunus bin Abi Ishaq, and Shu'bah reported Ahadith from Buraid bin Abi Maryam]}}
\hadithdefcmd{tirmidhi}{1633}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا ابْنُ الْمُبَارَكِ، عَنْ عَبْدِ الرَّحْمَنِ بْنِ عَبْدِ اللَّهِ الْمَسْعُودِيِّ، عَنْ مُحَمَّدِ بْنِ عَبْدِ الرَّحْمَنِ، عَنْ عِيسَى بْنِ طَلْحَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يَلِجُ النَّارَ رَجُلٌ بَكَى مِنْ خَشْيَةِ اللَّهِ حَتَّى يَعُودَ اللَّبَنُ فِي الضَّرْعِ وَلاَ يَجْتَمِعُ غُبَارٌ فِي سَبِيلِ اللَّهِ وَدُخَانُ جَهَنَّمَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَمُحَمَّدُ بْنُ عَبْدِ الرَّحْمَنِ هُوَ مَوْلَى أَبِي طَلْحَةَ مَدَنِيٌّ ‏.‏\hadithno{1633}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said, "A man who wept out of the fear of Allah shall not enter the Fire until the milk returns to the udder; and dust in the cause of Allah and the smoke of Hell shall not come together." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Muhammad bin 'Abdur-Rahman is freed slave of Abu Talhah, and he is from Al-Madinah}}
\hadithdefcmd{tirmidhi}{1634}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ عَمْرِو بْنِ مُرَّةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، أَنَّ شُرَحْبِيلَ بْنَ السِّمْطِ، قَالَ يَا كَعْبُ بْنَ مُرَّةَ حَدِّثْنَا عَنْ رَسُولِ اللَّهِ صلى الله عليه وسلم وَاحْذَرْ ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ شَابَ شَيْبَةً فِي الإِسْلاَمِ كَانَتْ لَهُ نُورًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ فَضَالَةَ بْنِ عُبَيْدٍ وَعَبْدِ اللَّهِ بْنِ عَمْرٍو ‏.‏ وَحَدِيثُ كَعْبِ بْنِ مُرَّةَ حَدِيثٌ حَسَنٌ ‏.‏ هَكَذَا رَوَاهُ الأَعْمَشُ عَنْ عَمْرِو بْنِ مُرَّةَ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ مَنْصُورٍ عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ وَأَدْخَلَ بَيْنَهُ وَبَيْنَ كَعْبِ بْنِ مُرَّةَ فِي الإِسْنَادِ رَجُلاً ‏.‏ وَيُقَالُ كَعْبُ بْنُ مُرَّةَ وَيُقَالُ مُرَّةُ بْنُ كَعْبٍ الْبَهْزِيُّ وَالْمَعْرُوفُ مِنْ أَصْحَابِ النَّبِيِّ صلى الله عليه وسلم مُرَّةُ بْنُ كَعْبٍ الْبَهْزِيُّ وَقَدْ رَوَى عَنِ النَّبِيِّ صلى الله عليه وسلم أَحَادِيثَ ‏.‏\hadithno{1634}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Shurahbil bin As-Samt: "O Ka'b bin Murrah! Relate (something) to is from the Messenger of Allah (ﷺ), and be cautious. He said: 'I heard the Prophet (ﷺ) say: "Whoever develops some gray hair in Islam, it shall be a light from him on the Day of Judgement." [Abu 'Eisa said:] There is something on this topic from Fadalah bin 'Ubaid and 'Abdullah bin 'Amr. The narration of Ka'b bin Murrah was reported like this from Al-A'mash, from 'Amr bin Murrah. This Hadith is been reported from Mansur, from Salim bin Abu Al-Ja'd, and he included a man between him and between Ka'b bin Murrah in the chain. He is called: "Ka'b bin Murrah," and he is called: "Murrah bin Ka'b Al-Bahzi," and the one known among the Companions of the Prophet (ﷺ) is Ka'b bin Murrah Al-Bahzi, he reported some Ahadith from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1635}{حَدَّثَنَا إِسْحَاقُ بْنُ مَنْصُورٍ الْمَرْوَزِيُّ، أَخْبَرَنَا حَيْوَةُ بْنُ شُرَيْحٍ الْحِمْصِيُّ، عَنْ بَقِيَّةَ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنْ كَثِيرِ بْنِ مُرَّةَ، عَنْ عَمْرِو بْنِ عَبَسَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ شَابَ شَيْبَةً فِي سَبِيلِ اللَّهِ كَانَتْ لَهُ نُورًا يَوْمَ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَحَيْوَةُ بْنُ شُرَيْحِ ابْنُ يَزِيدَ الْحِمْصِيُّ ‏.‏\hadithno{1635}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Amr bin 'Abasah: That the Messenger of Allah (ﷺ) said: "Whoever develops some gray hair in the cause of Allah, it shall be a light for him in the Day of Judgement. [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. As for Haiwah bin Shuraih, (the remainder of his name is) Ibn Yazid Al-Himsi}}
\hadithdefcmd{tirmidhi}{1636}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ الْخَيْلُ مَعْقُودٌ فِي نَوَاصِيهَا الْخَيْرُ إِلَى يَوْمِ الْقِيَامَةِ الْخَيْلُ لِثَلاَثَةٍ هِيَ لِرَجُلٍ أَجْرٌ وَهِيَ لِرَجُلٍ سِتْرٌ وَهِيَ عَلَى رَجُلٍ وِزْرٌ فَأَمَّا الَّذِي لَهُ أَجْرٌ فَالَّذِي يَتَّخِذُهَا فِي سَبِيلِ اللَّهِ فَيُعِدُّهَا لَهُ هِيَ لَهُ أَجْرٌ لاَ يَغِيبُ فِي بُطُونِهَا شَيْءٌ إِلاَّ كَتَبَ اللَّهُ لَهُ أَجْرًا ‏"‏ ‏.‏ وَفِي الْحَدِيثِ قِصَّةٌ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى مَالِكُ بْنُ أَنَسٍ عَنْ زَيْدِ بْنِ أَسْلَمَ عَنْ أَبِي صَالِحٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَ هَذَا ‏.‏\hadithno{1636}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "The forelocks of horses contain good until the Day of Judgement. The horse is for three (purposes): It is for one man a reward, and it is for one man a shelter (from poverty), and it is from one man a burden. As for the one who acquires it for the cause of Allah and then prepares it for that; it is for him a reward, nothing disappears into its stomach except that Allah writes it for him as a reward." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Malik bin Anas narrated similar to this Hadith from Zaid bin Aslam from Abu Salih from Abu Hurairah, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1637}{\hadithno{1637}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif}\hadithtrans{}}
\hadithdefcmd{tirmidhi}{1638}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، عَنْ أَبِيهِ، عَنْ قَتَادَةَ، عَنْ سَالِمِ بْنِ أَبِي الْجَعْدِ، عَنْ مَعْدَانَ بْنِ أَبِي طَلْحَةَ، عَنْ أَبِي نَجِيحٍ السُّلَمِيِّ، رضى الله عنه قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ مَنْ رَمَى بِسَهْمٍ فِي سَبِيلِ اللَّهِ فَهُوَ لَهُ عَدْلُ مُحَرَّرٍ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏ وَأَبُو نَجِيحٍ هُوَ عَمْرُو بْنُ عَبَسَةَ السُّلَمِيُّ وَعَبْدُ اللَّهِ بْنُ الأَزْرَقِ هُوَ عَبْدُ اللَّهِ بْنُ زَيْدٍ ‏.‏\hadithno{1638}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Najih As-Sulami: I heard the Messenger of Allah (ﷺ) say: "Whoever shoots an arrow in the cause of Allah, then he has the reward of freeing a slave." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Abu Najih is 'Amr bin 'Abasah As-Sulami, and 'Abdullah bin Al-Azraq is 'Abdullah bin Zaid}}
\hadithdefcmd{tirmidhi}{1639}{حَدَّثَنَا نَصْرُ بْنُ عَلِيٍّ الْجَهْضَمِيُّ، حَدَّثَنَا بِشْرُ بْنُ عُمَرَ، حَدَّثَنَا شُعَيْبُ بْنُ رُزَيْقٍ أَبُو شَيْبَةَ، حَدَّثَنَا عَطَاءٌ الْخُرَاسَانِيُّ، عَنْ عَطَاءِ بْنِ أَبِي رَبَاحٍ، عَنِ ابْنِ عَبَّاسٍ، قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ عَيْنَانِ لاَ تَمَسُّهُمَا النَّارُ عَيْنٌ بَكَتْ مِنْ خَشْيَةِ اللَّهِ وَعَيْنٌ بَاتَتْ تَحْرُسُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُثْمَانَ وَأَبِي رَيْحَانَةَ ‏.‏ وَحَدِيثُ ابْنِ عَبَّاسٍ حَدِيثٌ حَسَنٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ شُعَيْبِ بْنِ رُزَيْقٍ ‏.‏\hadithno{1639}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: "I heard the Messenger of Allah (ﷺ) saying, 'There are two eyes that shall not be touched by the Fire: An eye that wept from the fear of Allah, and an eye that spent the night standing on guard in the cause of Allah." [Abu 'Eisa said:] There are narrations on this topic from 'Uthman and Abu Raihanah. The Hadith of Ibn 'Abbas is a Hasan Gharib Hadith, we do not know of it except through the narration of Shu'aib bin Ruzaiq}}
\hadithdefcmd{tirmidhi}{1640}{حَدَّثَنَا يَحْيَى بْنُ طَلْحَةَ الْيَرْبُوعِيُّ الْكُوفِيُّ، حَدَّثَنَا أَبُو بَكْرِ بْنُ عَيَّاشٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏"‏ الْقَتْلُ فِي سَبِيلِ اللَّهِ يُكَفِّرُ كُلَّ خَطِيئَةٍ ‏"‏ ‏.‏ فَقَالَ جِبْرِيلُ إِلاَّ الدَّيْنَ ‏.‏ فَقَالَ النَّبِيُّ صلى الله عليه وسلم ‏"‏ إِلاَّ الدَّيْنَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ كَعْبِ بْنِ عُجْرَةَ وَجَابِرٍ وَأَبِي هُرَيْرَةَ وَأَبِي قَتَادَةَ ‏.‏ وَهَذَا حَدِيثٌ غَرِيبٌ لاَ نَعْرِفُهُ مِنْ حَدِيثِ أَبِي بَكْرٍ إِلاَّ مِنْ حَدِيثِ هَذَا الشَّيْخِ ‏.‏ قَالَ وَسَأَلْتُ مُحَمَّدَ بْنَ إِسْمَاعِيلَ عَنْ هَذَا الْحَدِيثِ فَلَمْ يَعْرِفْهُ وَقَالَ أُرَى أَنَّهُ أَرَادَ حَدِيثَ حُمَيْدٍ عَنْ أَنَسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏"‏ لَيْسَ أَحَدٌ مِنْ أَهْلِ الْجَنَّةِ يَسُرُّهُ أَنْ يَرْجِعَ إِلَى الدُّنْيَا إِلاَّ الشَّهِيدُ ‏"‏ ‏.‏\hadithno{1640}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Anas: That the Messenger of Allah (ﷺ) said: "Dying in the cause of Allah expiates every sin." Jibril said: "Except for debt." So the Messenger of Allah (ﷺ) said: "Except the debt." [Abu 'Eisa said:] There are narrations on this topic from Ka'b bin 'Ujrah, Jabir, Abu Hurairah, and Abu Qatadah. This Hadith is Gharib, we do not know of it as a Hadith of Abu Bakr (a narrator) except from this Shaikh (Yahya bin Talhah) He said: I asked Muhammad bin Isma'il about this Hadith and he did not know it. He said: "I think that he intended the Hadith of Humaid, from Anas, from the Prophet (ﷺ) that he said: 'There is none from the people of Paradise who would like to return to the world except for the martyr}}
\hadithdefcmd{tirmidhi}{1641}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، عَنْ عَمْرِو بْنِ دِينَارٍ، عَنِ الزُّهْرِيِّ، عَنِ ابْنِ كَعْبِ بْنِ مَالِكٍ، عَنْ أَبِيهِ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ إِنَّ أَرْوَاحَ الشُّهَدَاءِ فِي طَيْرٍ خُضْرٍ تَعْلُقُ مِنْ ثَمَرَةِ الْجَنَّةِ أَوْ شَجَرِ الْجَنَّةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1641}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Ka'b bin Malik: From his father that the Messenger of Allah (ﷺ) said: "The souls of the martyrs are in green birds, suspended from the fruit of Paradise, or the trees of Paradise." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1642}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا عُثْمَانُ بْنُ عُمَرَ، أَخْبَرَنَا عَلِيُّ بْنُ الْمُبَارَكِ، عَنْ يَحْيَى بْنِ أَبِي كَثِيرٍ، عَنْ عَامِرٍ الْعُقَيْلِيِّ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ عُرِضَ عَلَىَّ أَوَّلُ ثَلاَثَةٍ يَدْخُلُونَ الْجَنَّةَ شَهِيدٌ وَعَفِيفٌ مُتَعَفِّفٌ وَعَبْدٌ أَحْسَنَ عِبَادَةَ اللَّهِ وَنَصَحَ لِمَوَالِيهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1642}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said, "I was shown the first of (every) three to enter Paradise: A martyr, an 'Atif, who is a Muta'affif, and a slave who perfected his worship of Allah, and was sincere to his masters." [Abu 'Eisa said:] This Hadith is Hasan}}
\hadithdefcmd{tirmidhi}{1643}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، أَخْبَرَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم أَنَّهُ قَالَ ‏ "‏ مَا مِنْ عَبْدٍ يَمُوتُ لَهُ عِنْدَ اللَّهِ خَيْرٌ يُحِبُّ أَنْ يَرْجِعَ إِلَى الدُّنْيَا وَأَنَّ لَهُ الدُّنْيَا وَمَا فِيهَا إِلاَّ الشَّهِيدُ لِمَا يَرَى مِنْ فَضْلِ الشَّهَادَةِ فَإِنَّهُ يُحِبُّ أَنْ يَرْجِعَ إِلَى الدُّنْيَا فَيُقْتَلَ مَرَّةً أُخْرَى ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ قَالَ ابْنُ أَبِي عُمَرَ قَالَ سُفْيَانُ بْنُ عُيَيْنَةَ كَانَ عَمْرُو بْنُ دِينَارٍ أَسَنَّ مِنَ الزُّهْرِيِّ ‏.‏\hadithno{1643}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas: That the Prophet (ﷺ), "There is no person who dies having good (prepared for him) with Allah, who wishes to return to the world, and to have the world and all it contains, except for the martyr because of what he knows about the virtue of martyrdom. For, indeed he loves to return to the world so that he may be killed another time." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Ibn 'Umar said: "Sufyan bin 'Uyainah said: "Amr bin Dinar was older than Az-Zuhri}}
\hadithdefcmd{tirmidhi}{1644}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ عَطَاءِ بْنِ دِينَارٍ، عَنْ أَبِي يَزِيدَ الْخَوْلاَنِيِّ، أَنَّهُ سَمِعَ فَضَالَةَ بْنَ عُبَيْدٍ، يَقُولُ سَمِعْتُ عُمَرَ بْنَ الْخَطَّابِ، يَقُولُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏"‏ الشُّهَدَاءُ أَرْبَعَةٌ رَجُلٌ مُؤْمِنٌ جَيِّدُ الإِيمَانِ لَقِيَ الْعَدُوَّ فَصَدَقَ اللَّهَ حَتَّى قُتِلَ فَذَلِكَ الَّذِي يَرْفَعُ النَّاسُ إِلَيْهِ أَعْيُنَهُمْ يَوْمَ الْقِيَامَةِ هَكَذَا ‏"‏ ‏.‏ وَرَفَعَ رَأْسَهُ حَتَّى وَقَعَتْ قَلَنْسُوَتُهُ ‏.‏ قَالَ فَمَا أَدْرِي أَقَلَنْسُوَةَ عُمَرَ أَرَادَ أَمْ قَلَنْسُوَةَ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏"‏ وَرَجُلٌ مُؤْمِنٌ جَيِّدُ الإِيمَانِ لَقِيَ الْعَدُوَّ فَكَأَنَّمَا ضُرِبَ جِلْدُهُ بِشَوْكِ طَلْحٍ مِنَ الْجُبْنِ أَتَاهُ سَهْمٌ غَرْبٌ فَقَتَلَهُ فَهُوَ فِي الدَّرَجَةِ الثَّانِيَةِ وَرَجُلٌ مُؤْمِنٌ خَلَطَ عَمَلاً صَالِحًا وَآخَرَ سَيِّئًا لَقِيَ الْعَدُوَّ فَصَدَقَ اللَّهَ حَتَّى قُتِلَ فَذَلِكَ فِي الدَّرَجَةِ الثَّالِثَةِ وَرَجُلٌ مُؤْمِنٌ أَسْرَفَ عَلَى نَفْسِهِ لَقِيَ الْعَدُوَّ فَصَدَقَ اللَّهَ حَتَّى قُتِلَ فَذَلِكَ فِي الدَّرَجَةِ الرَّابِعَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَطَاءِ بْنِ دِينَارٍ ‏.‏ قَالَ سَمِعْتُ مُحَمَّدًا يَقُولُ قَدْ رَوَى سَعِيدُ بْنُ أَبِي أَيُّوبَ هَذَا الْحَدِيثَ عَنْ عَطَاءِ بْنِ دِينَارٍ وَقَالَ عَنْ أَشْيَاخٍ مِنْ خَوْلاَنَ وَلَمْ يَذْكُرْ فِيهِ عَنْ أَبِي يَزِيدَ ‏.‏ وَقَالَ عَطَاءُ بْنُ دِينَارٍ لَيْسَ بِهِ بَأْسٌ ‏.‏\hadithno{1644}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Fadalah bin 'Ubaid: That he heard 'Umar bin Al-Khattab saying: "I heard the Messenger of Allah (ﷺ) saying: 'The martyrs are four: A believing man whose faith is good, he meets the enemy and proves faithful to Allah until he is killed. That is the one to whom the people will raise up their eyes like this on the Day of Judgement' and he raised his head until his Qalansuwah fell - [he said:] I do not know if it was 'Umar's Qalansuwah or the Qalansuwah of the Prophet (ﷺ) that fell - he said, 'And a believing man whose faith is good (but not as brave as first), he meets the enemy, but due to cowardice, it only appears that he was struck with a thorn of an acacia tree when an unexpected arrow comes to him, yet it kills him. He is among the second level. And a believing man who has mixed righteous deed with another evil one, he meets his enemy and proves faithful to Allah until he is killed. This one is in the third level. And a believing man who wasted himself (in wrongdoing), he meets the enemy and proves faithful to Allah until he is killed. This one is in the fourth level.'" [Abu 'Eisa said:] This Hadith is Hasan Gharib, it is not known except as a narration of 'Ata bin Dinar. He said: I heard Muhammad saying: "Sa'eed bin Abi Ayyub reported this Hadith from 'Ata bin Dinar - from some Shaikhs of Khawlan - and he did not mention 'from Abu Yazid' in it." And he said: "'Ata bin Dinar; there is no harm in him}}
\hadithdefcmd{tirmidhi}{1645}{حَدَّثَنَا إِسْحَاقُ بْنُ مُوسَى الأَنْصَارِيُّ، حَدَّثَنَا مَعْنٌ، حَدَّثَنَا مَالِكٌ، عَنْ إِسْحَاقَ بْنِ عَبْدِ اللَّهِ بْنِ أَبِي طَلْحَةَ، عَنْ أَنَسِ بْنِ مَالِكٍ، أَنَّهُ سَمِعَهُ يَقُولُ كَانَ رَسُولُ اللَّهِ صلى الله عليه وسلم يَدْخُلُ عَلَى أُمِّ حَرَامٍ بِنْتِ مِلْحَانَ فَتُطْعِمُهُ وَكَانَتْ أُمُّ حَرَامٍ تَحْتَ عُبَادَةَ بْنِ الصَّامِتِ فَدَخَلَ عَلَيْهَا رَسُولُ اللَّهِ صلى الله عليه وسلم يَوْمًا فَأَطْعَمَتْهُ وَجَلَسَتْ تَفْلِي رَأْسَهُ فَنَامَ رَسُولُ اللَّهِ صلى الله عليه وسلم ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ قَالَتْ فَقُلْتُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ يَرْكَبُونَ ثَبَجَ هَذَا الْبَحْرِ مُلُوكٌ عَلَى الأَسِرَّةِ أَوْ مِثْلُ الْمُلُوكِ عَلَى الأَسِرَّةِ ‏"‏ ‏.‏ قُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ فَدَعَا لَهَا ثُمَّ وَضَعَ رَأْسَهُ فَنَامَ ثُمَّ اسْتَيْقَظَ وَهُوَ يَضْحَكُ قَالَتْ فَقُلْتُ لَهُ مَا يُضْحِكُكَ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ نَاسٌ مِنْ أُمَّتِي عُرِضُوا عَلَىَّ غُزَاةً فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ نَحْوَ مَا قَالَ فِي الأَوَّلِ قَالَتْ فَقُلْتُ يَا رَسُولَ اللَّهِ ادْعُ اللَّهَ أَنْ يَجْعَلَنِي مِنْهُمْ ‏.‏ قَالَ ‏"‏ أَنْتِ مِنَ الأَوَّلِينَ ‏"‏ ‏.‏ قَالَ فَرَكِبَتْ أُمُّ حَرَامٍ الْبَحْرَ فِي زَمَانِ مُعَاوِيَةَ بْنِ أَبِي سُفْيَانَ فَصُرِعَتْ عَنْ دَابَّتِهَا حِينَ خَرَجَتْ مِنَ الْبَحْرِ فَهَلَكَتْ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَأُمُّ حَرَامٍ بِنْتُ مِلْحَانَ هِيَ أُخْتُ أُمِّ سُلَيْمٍ وَهِيَ خَالَةُ أَنَسِ بْنِ مَالِكٍ ‏.‏\hadithno{1645}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Ishaq bin 'Abdullah bin Abi Talhah: That he heard Anas [bin Malik] saying: "The Messenger of Allah (ﷺ) used to visit Umm Haram bint Milhan, who would offer him meals. Umm Haram was the wife of 'Ubadah bin As-Samit. Once the Messenger of Allah (ﷺ) visited her and she provide him with some food and started inspecting this head for lice. Then the Messenger of Allah (ﷺ) slept and afterwards he awoke smiling. She said: 'I said: "What causes you to smile, O the Messenger of Allah (ﷺ) ?" He said: "Some of my followers who were displayed before me )in a dream) as fighters in Allah's cause, riding on a ship this ocean who were kings upon thrones, or like kings upon thrones." I said: "O Messenger of Allah! Supplicate to Allah to make me among them.'" So he supplicated for her. Then he lay down his head to sleep. Then he woke up and he was smiling. She said: 'So I said to him: "What causes you to smile, O the Messenger of Allah (ﷺ)?" He said: "Some of my followers who were displayed before me (in a dream) as fighters in Allah's cause," and he said similar to what he said earlier. She said: 'I said: "O Messenger of Allah! Supplicate to Allah to make me among them." He said: "You are the earlier ones.'" He said: "So Umm Haram rode on the sea during the time of Mu'awiyah bin Abu Sufyan. She was thrown from the riding animal after she arrived from the ocean voyage, and she died." [Abu 'Eisa said:] This Hadith is Hasan Sahih. Umm Haram bint Milhan is the daughter of Umm Sulaim, the maternal aunt of Anas bin Malik}}
\hadithdefcmd{tirmidhi}{1646}{حَدَّثَنَا هَنَّادٌ، حَدَّثَنَا أَبُو مُعَاوِيَةَ، عَنِ الأَعْمَشِ، عَنْ شَقِيقِ بْنِ سَلَمَةَ، عَنْ أَبِي مُوسَى، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم عَنِ الرَّجُلِ يُقَاتِلُ شَجَاعَةً وَيُقَاتِلُ حَمِيَّةً وَيُقَاتِلُ رِيَاءً فَأَىُّ ذَلِكَ فِي سَبِيلِ اللَّهِ قَالَ ‏ "‏ مَنْ قَاتَلَ لِتَكُونَ كَلِمَةُ اللَّهِ هِيَ الْعُلْيَا فَهُوَ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ عُمَرَ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1646}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Musa: "The Messenger of Allah (ﷺ) was asked about a man who fights out of bravery, one who fights out of protection (for himself or others), and one who fought to be seen. Which of them is in the cause of Allah ? He said: 'Whoever fought so that the Word of Allah is supreme, then he is in Allah's cause.'" [Abu 'Eisa said:] There is something on this topic from 'Umar. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1647}{حَدَّثَنَا مُحَمَّدُ بْنُ الْمُثَنَّى، حَدَّثَنَا عَبْدُ الْوَهَّابِ الثَّقَفِيُّ، عَنْ يَحْيَى بْنِ سَعِيدٍ، عَنْ مُحَمَّدِ بْنِ إِبْرَاهِيمَ، عَنْ عَلْقَمَةَ بْنِ وَقَّاصٍ اللَّيْثِيِّ، عَنْ عُمَرَ بْنِ الْخَطَّابِ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّمَا الأَعْمَالُ بِالنِّيَّةِ وَإِنَّمَا لاِمْرِئٍ مَا نَوَى فَمَنْ كَانَتْ هِجْرَتُهُ إِلَى اللَّهِ وَإِلَى رَسُولِهِ فَهِجْرَتُهُ إِلَى اللَّهِ وَرَسُولِهِ وَمَنْ كَانَتْ هِجْرَتُهُ إِلَى دُنْيَا يُصِيبُهَا أَوِ امْرَأَةٍ يَتَزَوَّجُهَا فَهِجْرَتُهُ إِلَى مَا هَاجَرَ إِلَيْهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏ وَقَدْ رَوَى مَالِكُ بْنُ أَنَسٍ وَسُفْيَانُ الثَّوْرِيُّ وَغَيْرُ وَاحِدٍ مِنَ الأَئِمَّةِ هَذَا عَنْ يَحْيَى بْنِ سَعِيدٍ وَلاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ يَحْيَى بْنِ سَعِيدٍ الأَنْصَارِيِّ ‏.‏ قَالَ عَبْدُ الرَّحْمَنِ بْنُ مَهْدِيٍّ يَنْبَغِي أَنْ نَضَعَ هَذَا الْحَدِيثَ فِي كُلِّ بَابٍ ‏.‏\hadithno{1647}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated 'Umar bin Al-Khattab: That the Messenger of Allah (ﷺ) said: "Deeds are but with intentions, and for the man is only what he intended. So one whose emigration was to Allah and His Messenger, then his emigration was to Allah and His Messenger. And one whose emigration was to the world, to attain some of it, or woman, to marry her, then his emigration was to what he emigrated. [Abu 'Eisa said:] This Hadith is Hasan Sahih. Malik bin Anas, Sufyan Ath-Thawri and more than one of the A'immah narrated this Hadith from Yahya bin Sa'eed. And we do not know of it except as a narration from Yahya bin Sa'eed Al-Ansari. 'Abdur Rahman bin Mahdi said: "It is necessary that we put this Hadith in every chapter}}
\hadithdefcmd{tirmidhi}{1648}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا الْعَطَّافُ بْنُ خَالِدٍ الْمَخْزُومِيُّ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ السَّاعِدِيِّ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ غَدْوَةٌ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا وَمَوْضِعُ سَوْطٍ فِي الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى وَفِي الْبَابِ عَنْ أَبِي هُرَيْرَةَ وَابْنِ عَبَّاسٍ وَأَبِي أَيُّوبَ وَأَنَسٍ ‏.‏ وَهَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1648}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Sahl bin Sa'd As-Sa'idi: That the Messenger of Allah (ﷺ) said: "Going out in the morning in the cause of Allah is better that the world and what is in it. And the place (the size) of a whip in Paradise is better than the world and what is in it." [Abu 'Eisa said:] There are narrations on this topic from Abu Hurairah, Ibn 'Abbas, Abu Ayyub, and Anas. This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1649}{حَدَّثَنَا أَبُو سَعِيدٍ الأَشَجُّ، حَدَّثَنَا أَبُو خَالِدٍ الأَحْمَرُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ أَبِي حَازِمٍ، عَنْ أَبِي هُرَيْرَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم وَالْحَجَّاجُ عَنِ الْحَكَمِ، عَنْ مِقْسَمٍ، عَنِ ابْنِ عَبَّاسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ غَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ وَأَبُو حَازِمٍ الَّذِي رَوَى عَنْ سَهْلِ بْنِ سَعْدٍ هُوَ أَبُو حَازِمٍ الزَّاهِدُ وَهُوَ مَدَنِيٌّ وَاسْمُهُ سَلَمَةُ بْنُ دِينَارٍ ‏.‏ وَأَبُو حَازِمٍ هَذَا الَّذِي رَوَى عَنْ أَبِي هُرَيْرَةَ هُوَ أَبُو حَازِمٍ الأَشْجَعِيُّ الْكُوفِيُّ وَاسْمُهُ سَلْمَانُ وَهُوَ مَوْلَى عَزَّةَ الأَشْجَعِيَّةِ ‏.‏\hadithno{1649}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Abu Hurairah and Ibn 'Abbas: That the Prophet (ﷺ) said: "Going out in the morning in the cause of Allah, or in the afternoon, is better than the world and what is in it." [Abu 'Eisa said:] This Hadith is Hasan Gharib. The Abu Hazim who reported from Ashl bin Sa'd is Abu Hazim Az-Zahid. He is from Al-Madinah, and his name is Salamah bin Dinar. While [this] Abu Hazim who reported from Abu Hurairah is Abu Hazim Al-Ashja'i Al-Kufi, whose name is Salman, and he is the freed slave of 'Azzah Al-Ashja'iyyah}}
\hadithdefcmd{tirmidhi}{1650}{حَدَّثَنَا عُبَيْدُ بْنُ أَسْبَاطِ بْنِ مُحَمَّدٍ الْقُرَشِيُّ الْكُوفِيُّ، حَدَّثَنَا أَبِي، عَنْ هِشَامِ بْنِ سَعْدٍ، عَنْ سَعِيدِ بْنِ أَبِي هِلاَلٍ، عَنِ ابْنِ أَبِي ذُبَابٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ مَرَّ رَجُلٌ مِنْ أَصْحَابِ رَسُولِ اللَّهِ صلى الله عليه وسلم بِشِعْبٍ فِيهِ عُيَيْنَةٌ مِنْ مَاءٍ عَذْبَةٌ فَأَعْجَبَتْهُ لِطِيبِهَا فَقَالَ لَوِ اعْتَزَلْتُ النَّاسَ فَأَقَمْتُ فِي هَذَا الشِّعْبِ وَلَنْ أَفْعَلَ حَتَّى أَسْتَأْذِنَ رَسُولَ اللَّهِ صلى الله عليه وسلم ‏.‏ فَذَكَرَ ذَلِكَ لِرَسُولِ اللَّهِ صلى الله عليه وسلم فَقَالَ ‏ "‏ لاَ تَفْعَلْ فَإِنَّ مَقَامَ أَحَدِكُمْ فِي سَبِيلِ اللَّهِ أَفْضَلُ مِنْ صَلاَتِهِ فِي بَيْتِهِ سَبْعِينَ عَامًا أَلاَ تُحِبُّونَ أَنْ يَغْفِرَ اللَّهُ لَكُمْ وَيُدْخِلَكُمُ الْجَنَّةَ اغْزُوا فِي سَبِيلِ اللَّهِ مَنْ قَاتَلَ فِي سَبِيلِ اللَّهِ فُوَاقَ نَاقَةٍ وَجَبَتْ لَهُ الْجَنَّةُ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1650}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: A man from the Companions of the Prophet (ﷺ) passed by ravine containing a small spring of thirst quenching water, so he was amazed by how pleasant it was. So he said: 'I should leave the people and stay in this ravine. But I will not do it until I seek permission from the Messenger of Allah (ﷺ).' So he mentioned that to the Messenger of Allah (ﷺ) and he said: 'Do not do so. For indeed one of you standing in the cause of Allah is more virtuous that his Salat in his house for seventy years. Do you not love that Allah forgive your sins and admit you into Paradise ? Then fight in the cause of Allah, for whoever fights in Allah's cause for the time it takes for two milkings of a camel, then Paradise is obligatory for him.'" [Abu 'Eisa said:] This Hadith is Hasan}}
\hadithdefcmd{tirmidhi}{1651}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا إِسْمَاعِيلُ بْنُ جَعْفَرٍ، عَنْ حُمَيْدٍ، عَنْ أَنَسٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ لَغَدْوَةٌ فِي سَبِيلِ اللَّهِ أَوْ رَوْحَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا وَلَقَابُ قَوْسِ أَحَدِكُمْ أَوْ مَوْضِعُ يَدِهِ فِي الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا وَلَوْ أَنَّ امْرَأَةً مِنْ نِسَاءِ أَهْلِ الْجَنَّةِ اطَّلَعَتْ إِلَى الأَرْضِ لأَضَاءَتْ مَا بَيْنَهُمَا وَلَمَلأَتْ مَا بَيْنَهُمَا رِيحًا وَلَنَصِيفُهَا عَلَى رَأْسِهَا خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1651}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Anas: That the Messenger of Allah (ﷺ) said: "To go out in the cause of Allah in the morning, or the afternoon, is better than the world and what is in it. And the space that a bow of one of you - or the space that his hand - would occupy in Paradise is better than the world and what is in it. And if a woman among the women inhabiting Paradise were to appear to the people of the earth, then she would illuminate what is between the ( the heavens and the earth), and a pleasant scent would fill up what is between them, and the scarf on her head is better than the world and what is in it." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1652}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا ابْنُ لَهِيعَةَ، عَنْ بُكَيْرِ بْنِ عَبْدِ اللَّهِ بْنِ الأَشَجِّ، عَنْ عَطَاءِ بْنِ يَسَارٍ، عَنِ ابْنِ عَبَّاسٍ، أَنَّ النَّبِيَّ صلى الله عليه وسلم قَالَ ‏ "‏ أَلاَ أُخْبِرُكُمْ بِخَيْرِ النَّاسِ رَجُلٌ مُمْسِكٌ بِعِنَانِ فَرَسِهِ فِي سَبِيلِ اللَّهِ أَلاَ أُخْبِرُكُمْ بِالَّذِي يَتْلُوهُ رَجُلٌ مُعْتَزِلٌ فِي غُنَيْمَةٍ لَهُ يُؤَدِّي حَقَّ اللَّهِ فِيهَا أَلاَ أُخْبِرُكُمْ بِشَرِّ النَّاسِ رَجُلٌ يُسْأَلُ بِاللَّهِ وَلاَ يُعْطِي بِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ مِنْ هَذَا الْوَجْهِ وَيُرْوَى هَذَا الْحَدِيثُ مِنْ غَيْرِ وَجْهٍ عَنِ ابْنِ عَبَّاسٍ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1652}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Ibn 'Abbas: That the Prophet (ﷺ) said: "Shall I not inform you of the best of the people ? A man who takes hold of the reins of his horse in Allah's cause. Shall I not inform you of the one who comes after him ? The man who secludes himself from the people with a small group of sheep of his, thereby fulfilling Allah's right. Shall I not inform you about the worst of the people ? A man who is asked by (the Name of) Allah, but not given by Him." [Abu 'Eisa said:] This Hadith is Hasan Gharib from this route. This Hadith has been reported through other routes from Ibn 'Abbas, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1653}{حَدَّثَنَا مُحَمَّدُ بْنُ سَهْلِ بْنِ عَسْكَرٍ الْبَغْدَادِيُّ، حَدَّثَنَا الْقَاسِمُ بْنُ كَثِيرٍ الْمِصْرِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ، أَنَّهُ سَمِعَ سَهْلَ بْنَ أَبِي أُمَامَةَ بْنِ سَهْلِ بْنِ حُنَيْفٍ، يُحَدِّثُ عَنْ أَبِيهِ، عَنْ جَدِّهِ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَأَلَ اللَّهَ الشَّهَادَةَ مِنْ قَلْبِهِ صَادِقًا بَلَّغَهُ اللَّهُ مَنَازِلَ الشُّهَدَاءِ وَإِنْ مَاتَ عَلَى فِرَاشِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى حَدِيثُ سَهْلِ بْنِ حُنَيْفٍ حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ عَبْدِ الرَّحْمَنِ بْنِ شُرَيْحٍ ‏.‏ وَقَدْ رَوَاهُ عَبْدُ اللَّهِ بْنُ صَالِحٍ عَنْ عَبْدِ الرَّحْمَنِ بْنِ شُرَيْحٍ ‏.‏ وَعَبْدُ الرَّحْمَنِ بْنُ شُرَيْحٍ يُكْنَى أَبَا شُرَيْحٍ وَهُوَ إِسْكَنْدَرَانِيٌّ ‏.‏ وَفِي الْبَابِ عَنْ مُعَاذِ بْنِ جَبَلٍ ‏.‏\hadithno{1653}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Sahl bin Abi Umamah bin Sahl bin Hunaif: From his father, from his grandfather, that the Prophet (ﷺ) said: "Whoever asks Allah for Martyrdom sincerely in his heart, Allah will grant the status of martyrdom for him, even if he were to die in his bed." [Abu 'Eisa said:] This Hadith is Hasan Gharib as a narration of Sahl bin Hunaif. We do not know of it except from the report of 'Abdur-Rahman bin Shuraih. 'Abdullah bin Salih reported it from 'Abdur-Rahman bin Shuraih, and 'Abdur-Rahman bin Shuraih's kunyah is Abu Shuriah, and he is from Iskandarani. There is something on this topic from Mu'adh bin Jabal}}
\hadithdefcmd{tirmidhi}{1654}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ مَالِكِ بْنِ يُخَامِرَ السَّكْسَكِيِّ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ سَأَلَ اللَّهَ الْقَتْلَ فِي سَبِيلِهِ صَادِقًا مِنْ قَلْبِهِ أَعْطَاهُ اللَّهُ أَجْرَ الشَّهِيدِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1654}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Mu’adh bin Jabal : That the Prophet (ﷺ) said: "Whoever asks Allah to be killed in His cause sincerely from his heart, Allah shall give him the reward of martyrdom. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1655}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا اللَّيْثُ، عَنِ ابْنِ عَجْلاَنَ، عَنْ سَعِيدٍ الْمَقْبُرِيِّ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ ثَلاَثَةٌ حَقٌّ عَلَى اللَّهِ عَوْنُهُمُ الْمُجَاهِدُ فِي سَبِيلِ اللَّهِ وَالْمُكَاتَبُ الَّذِي يُرِيدُ الأَدَاءَ وَالنَّاكِحُ الَّذِي يُرِيدُ الْعَفَافَ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1655}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "There are three for whom it is a right upon Allah to help him: The Mujahid in the cause of Allah, the Mukatab who intends to fulfill (the Kitabah), and the one getting married who intends chastity." [Abu 'Eisa said:] This Hadith is Hasan}}
\hadithdefcmd{tirmidhi}{1656}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا عَبْدُ الْعَزِيزِ بْنُ مُحَمَّدٍ، عَنْ سُهَيْلِ بْنِ أَبِي صَالِحٍ، عَنْ أَبِيهِ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لاَ يُكْلَمُ أَحَدٌ فِي سَبِيلِ اللَّهِ وَاللَّهُ أَعْلَمُ بِمَنْ يُكْلَمُ فِي سَبِيلِهِ إِلاَّ جَاءَ يَوْمَ الْقِيَامَةِ اللَّوْنُ لَوْنُ الدَّمِ وَالرِّيحُ رِيحُ الْمِسْكِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1656}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "None is wounded in Allah's cause - and Allah knows better about who has been injured in His cause - except that he will come on the Day of Resurrection with his wound the color of blood but its scent will be the scent of musk." [Abu 'Eisa said:] This Hadith is Hasan Sahih. It has been reported through other routes from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1657}{حَدَّثَنَا أَحْمَدُ بْنُ مَنِيعٍ، حَدَّثَنَا رَوْحُ بْنُ عُبَادَةَ، حَدَّثَنَا ابْنُ جُرَيْجٍ، عَنْ سُلَيْمَانَ بْنِ مُوسَى، عَنْ مَالِكِ بْنِ يُخَامِرَ، عَنْ مُعَاذِ بْنِ جَبَلٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ مَنْ قَاتَلَ فِي سَبِيلِ اللَّهِ مِنْ رَجُلٍ مُسْلِمٍ فُوَاقَ نَاقَةٍ وَجَبَتْ لَهُ الْجَنَّةُ وَمَنْ جُرِحَ جُرْحًا فِي سَبِيلِ اللَّهِ أَوْ نُكِبَ نَكْبَةً فَإِنَّهَا تَجِئُ يَوْمَ الْقِيَامَةِ كَأَغْزَرِ مَا كَانَتْ لَوْنُهَا الزَّعْفَرَانُ وَرِيحُهَا كَالْمِسْكِ ‏"‏ ‏.‏ هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1657}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Mu’adh bin Jabal : That the Prophet (ﷺ) said: "Whoever fought in the cause of Allah - a Muslim man - for the time it takes for two milkings of a camel, then Paradise is obligatory for him. And whoever suffered a wound in the cause of Allah, or he suffers from an injury, then he will come on the Day of Resurrection while (his blood will be) more copius that it ever was, its color the color of saffron, and its scent like that of musk." This Hadith is Sahih}}
\hadithdefcmd{tirmidhi}{1658}{حَدَّثَنَا أَبُو كُرَيْبٍ، حَدَّثَنَا عَبْدَةُ بْنُ سُلَيْمَانَ، عَنْ مُحَمَّدِ بْنِ عَمْرٍو، حَدَّثَنَا أَبُو سَلَمَةَ، عَنْ أَبِي هُرَيْرَةَ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ الأَعْمَالِ أَفْضَلُ أَوْ أَىُّ الأَعْمَالِ خَيْرٌ قَالَ ‏"‏ إِيمَانٌ بِاللَّهِ وَرَسُولِهِ ‏"‏ ‏.‏ قِيلَ ثُمَّ أَىُّ شَيْءٍ قَالَ ‏"‏ الْجِهَادُ سَنَامُ الْعَمَلِ ‏"‏ ‏.‏ قِيلَ ثُمَّ أَىُّ شَيْءٍ يَا رَسُولَ اللَّهِ قَالَ ‏"‏ ثُمَّ حَجٌّ مَبْرُورٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ وَقَدْ رُوِيَ مِنْ غَيْرِ وَجْهٍ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏\hadithno{1658}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Hurairah: "The Messenger of Allah (ﷺ) was asked: 'Which deed is the most virtuos ? And which deed is the best ?' He (ﷺ) said: 'Faith in Allah and His Messenger.' It was said: 'Then what ?' He said: 'Jihad is the hump (the most prominent) of the deeds.' Then what O Messenger of Allah ? He said: 'Then Hajj Mabrur.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih, it has been reported through other routes from Abu Hurairah from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1659}{حَدَّثَنَا قُتَيْبَةُ، حَدَّثَنَا جَعْفَرُ بْنُ سُلَيْمَانَ الضُّبَعِيُّ، عَنْ أَبِي عِمْرَانَ الْجَوْنِيِّ، عَنْ أَبِي بَكْرِ بْنِ أَبِي مُوسَى الأَشْعَرِيِّ، قَالَ سَمِعْتُ أَبِي بِحَضْرَةِ الْعَدُوِّ، يَقُولُ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ إِنَّ أَبْوَابَ الْجَنَّةِ تَحْتَ ظِلاَلِ السُّيُوفِ ‏"‏ ‏.‏ فَقَالَ رَجُلٌ مِنَ الْقَوْمِ رَثُّ الْهَيْئَةِ أَأَنْتَ سَمِعْتَ هَذَا مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم يَذْكُرُهُ قَالَ نَعَمْ ‏.‏ فَرَجَعَ إِلَى أَصْحَابِهِ فَقَالَ أَقْرَأُ عَلَيْكُمُ السَّلاَمَ ‏.‏ وَكَسَرَ جَفْنَ سَيْفِهِ فَضَرَبَ بِهِ حَتَّى قُتِلَ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ لاَ نَعْرِفُهُ إِلاَّ مِنْ حَدِيثِ جَعْفَرِ بْنِ سُلَيْمَانَ الضُّبَعِيِّ ‏.‏ وَأَبُو عِمْرَانَ الْجَوْنِيُّ اسْمُهُ عَبْدُ الْمَلِكِ بْنُ حَبِيبٍ وَأَبُو بَكْرِ بْنُ أَبِي مُوسَى قَالَ أَحْمَدُ بْنُ حَنْبَلٍ هُوَ اسْمُهُ ‏.‏\hadithno{1659}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih Muslim}\hadithtrans{Narrated Abu Bakr bin Abi Musa Al-Ash'ari: "I heard my father saying in the presence of the enemy: 'The Messenger of Allah (ﷺ) said: "Indeed, the gates of Paradise are under the shadows of the swords.'" A man among the people with ragged appearance said: 'Have you heard what you mentioned from the Messenger of Allah (ﷺ) ?' He said: 'Yes.' So he returned to his comrades and bid them Salam (farewell), broke the sheath of his sword, and began fighting with it until he was killed." [Abu 'Eisa said:] This Hadith is Sahih Gharib. We do not know it except as a narration of Ja'far bin Sulaiman [Ad-Dubai']. (One of the narrators) Abu 'Imran Al-Jawni's name is 'Abdul Malik bin Habib. As for Abu Bakr bin Abi Musa, Ahmad bin Hanbal said: "That is his name}}
\hadithdefcmd{tirmidhi}{1660}{حَدَّثَنَا أَبُو عَمَّارٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنِ الأَوْزَاعِيِّ، حَدَّثَنَا الزُّهْرِيُّ، عَنْ عَطَاءِ بْنِ يَزِيدَ اللَّيْثِيِّ، عَنْ أَبِي سَعِيدٍ الْخُدْرِيِّ، قَالَ سُئِلَ رَسُولُ اللَّهِ صلى الله عليه وسلم أَىُّ النَّاسِ أَفْضَلُ قَالَ ‏"‏ رَجُلٌ يُجَاهِدُ فِي سَبِيلِ اللَّهِ ‏"‏ ‏.‏ قَالُوا ثُمَّ مَنْ قَالَ ‏"‏ ثُمَّ مُؤْمِنٌ فِي شِعْبٍ مِنَ الشِّعَابِ يَتَّقِي رَبَّهُ وَيَدَعُ النَّاسَ مِنْ شَرِّهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1660}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Narrated Abu Sa’id Al Khudri : that the Messenger of Allah (ﷺ) was asked: "Which of the people are most virtuous?" He said: "A man who take part in Jihad in Allah's cause." They said: "Then whom?" He said: "Then a believer who stays in one of the mountains path out of Taqwa for his Lord, leaving the people secure from his evil." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1661}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُعَاذُ بْنُ هِشَامٍ، حَدَّثَنِي أَبِي، عَنْ قَتَادَةَ، حَدَّثَنَا أَنَسُ بْنُ مَالِكٍ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا مِنْ أَحَدٍ مِنْ أَهْلِ الْجَنَّةِ يَسُرُّهُ أَنْ يَرْجِعَ إِلَى الدُّنْيَا غَيْرُ الشَّهِيدِ فَإِنَّهُ يُحِبُّ أَنْ يَرْجِعَ إِلَى الدُّنْيَا يَقُولُ حَتَّى أُقْتَلَ عَشْرَ مَرَّاتٍ فِي سَبِيلِ اللَّهِ مِمَّا يَرَى مِمَّا أَعْطَاهُ اللَّهُ مِنَ الْكَرَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ ‏.‏\hadithno{1661}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Anas bin Malik: That the Messenger of Allah (ﷺ) said: "None of the people of Paradise would wish to return to the world except for the martyr who indeed would love to return to the world saying that he would love to be killed ten times in Allah's cause because of what he has seen of the honor that He has given him." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1662}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، حَدَّثَنَا مُحَمَّدُ بْنُ جَعْفَرٍ، حَدَّثَنَا شُعْبَةُ، عَنْ قَتَادَةَ، عَنْ أَنَسٍ، عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ بِمَعْنَاهُ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1662}\hadithgrade{Zubair Ali Zai: Sahih - Agreed Upon}\hadithtrans{Another chain from Anas, from the Prophet (ﷺ) with similar in its meaning. [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1663}{حَدَّثَنَا عَبْدُ اللَّهِ بْنُ عَبْدِ الرَّحْمَنِ، حَدَّثَنَا نُعَيْمُ بْنُ حَمَّادٍ، حَدَّثَنَا بَقِيَّةُ بْنُ الْوَلِيدِ، عَنْ بَحِيرِ بْنِ سَعْدٍ، عَنْ خَالِدِ بْنِ مَعْدَانَ، عَنِ الْمِقْدَامِ بْنِ مَعْدِيكَرِبَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ لِلشَّهِيدِ عِنْدَ اللَّهِ سِتُّ خِصَالٍ يُغْفَرُ لَهُ فِي أَوَّلِ دَفْعَةٍ وَيَرَى مَقْعَدَهُ مِنَ الْجَنَّةِ وَيُجَارُ مِنْ عَذَابِ الْقَبْرِ وَيَأْمَنُ مِنَ الْفَزَعِ الأَكْبَرِ وَيُوضَعُ عَلَى رَأْسِهِ تَاجُ الْوَقَارِ الْيَاقُوتَةُ مِنْهَا خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا وَيُزَوَّجُ اثْنَتَيْنِ وَسَبْعِينَ زَوْجَةً مِنَ الْحُورِ الْعِينِ وَيُشَفَّعُ فِي سَبْعِينَ مِنْ أَقَارِبِهِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1663}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Sahih; Zubair Ali Zai: Hasan}\hadithtrans{Narrated Al-Miqdam bin Ma'diykarib: That the Messenger of Allah (ﷺ) said: "There are six things with Allah for the martyr. He is forgiven with the first flow of blood (he suffers), he is shown his place in Paradise, he is protected from punishment in the grave, secured from the greatest terror, the crown of dignity is placed upon his head - and its gems are better than the world and what is in it - he is married to seventy two wives along Al-Huril-'Ayn of Paradise, and he may intercede for seventy of his close relatives." [Abu 'Eisa said:] This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1664}{حَدَّثَنَا أَبُو بَكْرِ بْنُ أَبِي النَّضْرِ، حَدَّثَنَا أَبُو النَّضْرِ الْبَغْدَادِيُّ، حَدَّثَنَا عَبْدُ الرَّحْمَنِ بْنُ عَبْدِ اللَّهِ بْنِ دِينَارٍ، عَنْ أَبِي حَازِمٍ، عَنْ سَهْلِ بْنِ سَعْدٍ، أَنَّ رَسُولَ اللَّهِ صلى الله عليه وسلم قَالَ ‏ "‏ رِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا وَمَوْضِعُ سَوْطِ أَحَدِكُمْ فِي الْجَنَّةِ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا وَلَرَوْحَةٌ يَرُوحُهَا الْعَبْدُ فِي سَبِيلِ اللَّهِ أَوْ لَغَدْوَةٌ خَيْرٌ مِنَ الدُّنْيَا وَمَا فِيهَا ‏"‏ ‏.‏ هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ ‏.‏\hadithno{1664}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Sahih - Bukhari And Muslim}\hadithtrans{Narrated Sahl bin Sa'd: That the Messenger of Allah (ﷺ) said: "(Ribat) Guarding the frontier for a day in the cause of Allah is better than the world and what is in it. And an afternoon the worshipper spends in the cause of Allah - or a morning - is better than the world and what is on it. And the space occupied by the whip of one of you in Paradise is better than the world and what is on it." This Hadith is Hasan Sahih}}
\hadithdefcmd{tirmidhi}{1665}{حَدَّثَنَا ابْنُ أَبِي عُمَرَ، حَدَّثَنَا سُفْيَانُ بْنُ عُيَيْنَةَ، حَدَّثَنَا مُحَمَّدُ بْنُ الْمُنْكَدِرِ، قَالَ مَرَّ سَلْمَانُ الْفَارِسِيُّ بِشُرَحْبِيلَ بْنِ السِّمْطِ وَهُوَ فِي مُرَابَطٍ لَهُ وَقَدْ شَقَّ عَلَيْهِ وَعَلَى أَصْحَابِهِ قَالَ أَلاَ أُحَدِّثُكَ يَا ابْنَ السِّمْطِ بِحَدِيثٍ سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم قَالَ بَلَى ‏.‏ قَالَ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ رِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ أَفْضَلُ وَرُبَّمَا قَالَ خَيْرٌ مِنْ صِيَامِ شَهْرٍ وَقِيَامِهِ وَمَنْ مَاتَ فِيهِ وُقِيَ فِتْنَةَ الْقَبْرِ وَنُمِّيَ لَهُ عَمَلُهُ إِلَى يَوْمِ الْقِيَامَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ ‏.‏\hadithno{1665}\hadithgrade{Ahmad Muhammad Shakir: Sahih; Al-Albani: Sahih; Zubair Ali Zai: Sahih}\hadithtrans{Narrated Muhammad bin Al-Munkadir: "Salman Al-Farisi passed by Shurahbil bin As-Simt while he was in garrison in which he and his companions were suffering from difficulties. He said to him: 'Shall I narrate to you - O Ibn As-Simt - a Hadith I heard from the Messenger of Allah (ﷺ) ?' He said: 'Of course.' He said: 'I heard the Messenger of Allah (ﷺ) saying: "(Ribat) Guarding the frontier for a day in the cause of Allah is more virtuous" - and perhaps he said: "better, than fasting a month and standing (in prayer) for it. And whoever dies in it, he is protected from the trials of the grave, and his deeds (continuously) multiplied until the Day of Resurrection. [Abu 'Eisa said:] This Hadith is Hasan}}
\hadithdefcmd{tirmidhi}{1666}{حَدَّثَنَا عَلِيُّ بْنُ حُجْرٍ، حَدَّثَنَا الْوَلِيدُ بْنُ مُسْلِمٍ، عَنْ إِسْمَاعِيلَ بْنِ رَافِعٍ، عَنْ سُمَىٍّ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَنْ لَقِيَ اللَّهَ بِغَيْرِ أَثَرٍ مِنْ جِهَادٍ لَقِيَ اللَّهَ وَفِيهِ ثُلْمَةٌ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ غَرِيبٌ مِنْ حَدِيثِ الْوَلِيدِ بْنِ مُسْلِمٍ عَنْ إِسْمَاعِيلَ بْنِ رَافِعٍ ‏.‏ وَإِسْمَاعِيلُ بْنُ رَافِعٍ قَدْ ضَعَّفَهُ بَعْضُ أَصْحَابِ الْحَدِيثِ ‏.‏ قَالَ وَسَمِعْتُ مُحَمَّدًا يَقُولُ هُوَ ثِقَةٌ مُقَارِبُ الْحَدِيثِ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ مِنْ غَيْرِ هَذَا الْوَجْهِ عَنْ أَبِي هُرَيْرَةَ عَنِ النَّبِيِّ صلى الله عليه وسلم ‏.‏ وَحَدِيثُ سَلْمَانَ إِسْنَادُهُ لَيْسَ بِمُتَّصِلٍ مُحَمَّدُ بْنُ الْمُنْكَدِرِ لَمْ يُدْرِكْ سَلْمَانَ الْفَارِسِيَّ ‏.‏ وَقَدْ رُوِيَ هَذَا الْحَدِيثُ عَنْ أَيُّوبَ بْنِ مُوسَى عَنْ مَكْحُولٍ عَنْ شُرَحْبِيلَ بْنِ السِّمْطِ عَنْ سَلْمَانَ عَنِ النَّبِيِّ صلى الله عليه وسلم نَحْوَهُ ‏.‏\hadithno{1666}\hadithgrade{Ahmad Muhammad Shakir: Daif; Al-Albani: Daif; Bashar Awad Maarouf: Daif; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "Whoever meets Allah without any traces from Jihad he meets Allah with a defect. [Abu 'Eisa said:] This Hadith is Gharib as a narration of Al-Walid bin Muslim from Isma'il bin Rafi'. Isma'il bin Rafi' was graded weak by some of the people of Hadith. I heard Muhammad saying: "He is trustworthy, average (Muqarib) in Hadith." This Hadith has been reported from Abu Hurairah from the Prophet (ﷺ) through other than this route. Regarding the Hadith of Salman, its chain is not connected, Muhammad bin Al-Munkadir did not see Salman Al-Farisi. This Hadith has been reported from Ayyub bin Musa, from Makhul, from Shurahbil bin As-Simt from Salman, from the Prophet (ﷺ)}}
\hadithdefcmd{tirmidhi}{1667}{حَدَّثَنَا الْحَسَنُ بْنُ عَلِيٍّ الْخَلاَّلُ، حَدَّثَنَا هِشَامُ بْنُ عَبْدِ الْمَلِكِ، حَدَّثَنَا اللَّيْثُ بْنُ سَعْدٍ، حَدَّثَنِي أَبُو عَقِيلٍ، زُهْرَةُ بْنُ مَعْبَدٍ عَنْ أَبِي صَالِحٍ، مَوْلَى عُثْمَانَ بْنِ عَفَّانَ قَالَ سَمِعْتُ عُثْمَانَ، وَهُوَ عَلَى الْمِنْبَرِ يَقُولُ إِنِّي كَتَمْتُكُمْ حَدِيثًا سَمِعْتُهُ مِنْ رَسُولِ اللَّهِ صلى الله عليه وسلم كَرَاهِيَةَ تَفَرُّقِكُمْ عَنِّي ثُمَّ بَدَا لِي أَنْ أُحَدِّثَكُمُوهُ لِيَخْتَارَ امْرُؤٌ لِنَفْسِهِ مَا بَدَا لَهُ سَمِعْتُ رَسُولَ اللَّهِ صلى الله عليه وسلم يَقُولُ ‏ "‏ رِبَاطُ يَوْمٍ فِي سَبِيلِ اللَّهِ خَيْرٌ مِنْ أَلْفِ يَوْمٍ فِيمَا سِوَاهُ مِنَ الْمَنَازِلِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏ وَقَالَ مُحَمَّدُ بْنُ إِسْمَاعِيلَ أَبُو صَالِحٍ مَوْلَى عُثْمَانَ اسْمُهُ تُرْكَانُ ‏.‏\hadithno{1667}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Sahih}\hadithtrans{Narrated Abu Salih, the Freed slave of Uthman : "I heard Uthman while on the Minbar saying: 'I did not inform you about a Hadith I had heard from the Messenger of Allah (ﷺ), out of dismay that you might part from me. Then it occurred to me that I should narrate to you so that one may choose from these matters accordingly. I heard the Messenger of Allah (ﷺ) saying: "(Ribat) Guarding the frontier for a day in Allah's cause is beter in status than thousand days doing other than that.'" [Abu 'Eisa said:] This Hadith is Hasan Sahih Gharib. Muhammad bin Ism'ail said: "Abu Salih, the freed slave of 'Uthman's name is Burkan}}
\hadithdefcmd{tirmidhi}{1668}{حَدَّثَنَا مُحَمَّدُ بْنُ بَشَّارٍ، وَأَحْمَدُ بْنُ نَصْرٍ النَّيْسَابُورِيُّ، وَغَيْرُ، وَاحِدٍ، قَالُوا حَدَّثَنَا صَفْوَانُ بْنُ عِيسَى، حَدَّثَنَا مُحَمَّدُ بْنُ عَجْلاَنَ، عَنِ الْقَعْقَاعِ بْنِ حَكِيمٍ، عَنْ أَبِي صَالِحٍ، عَنْ أَبِي هُرَيْرَةَ، قَالَ قَالَ رَسُولُ اللَّهِ صلى الله عليه وسلم ‏ "‏ مَا يَجِدُ الشَّهِيدُ مِنْ مَسِّ الْقَتْلِ إِلاَّ كَمَا يَجِدُ أَحَدُكُمْ مِنْ مَسِّ الْقَرْصَةِ ‏"‏ ‏.‏ قَالَ أَبُو عِيسَى هَذَا حَدِيثٌ حَسَنٌ صَحِيحٌ غَرِيبٌ ‏.‏\hadithno{1668}\hadithgrade{Ahmad Muhammad Shakir: Hasan Sahih; Al-Albani: Hasan Sahih; Bashar Awad Maarouf: Hasan Sahih; Zubair Ali Zai: Daif}\hadithtrans{Narrated Abu Hurairah: That the Messenger of Allah (ﷺ) said: "The martyr does not sense the touch of death except as one of you senses the touch of a (bug) bite. [Abu 'Eisa said:] This Hadith is Hasan Gharib Sahih}}
\hadithdefcmd{tirmidhi}{1669}{حَدَّثَنَا زِيَادُ بْنُ أَيُّوبَ، حَدَّثَنَا يَزِيدُ بْنُ هَارُونَ، أَنْبَأَنَا الْوَلِيدُ بْنُ جَمِيلٍ الْفِلَسْطِينِيُّ، عَنِ الْقَاسِمِ أَبِي عَبْدِ الرَّحْمَنِ، عَنْ أَبِي أُمَامَةَ، عَنِ النَّبِيِّ صلى الله عليه وسلم قَالَ ‏ "‏ لَيْسَ شَيْءٌ أَحَبَّ إِلَى اللَّهِ مِنْ قَطْرَتَيْنِ وَأَثَرَيْنِ قَطْرَةٌ مِنْ دُمُوعٍ فِي خَشْيَةِ اللَّهِ وَقَطْرَةُ دَمٍ تُهَرَاقُ فِي سَبِيلِ اللَّهِ ‏.‏ وَأَمَّا الأَثَرَانِ فَأَثَرٌ فِي سَبِيلِ اللَّهِ وَأَثَرٌ فِي فَرِيضَةٍ مِنْ فَرَائِضِ اللَّهِ ‏"‏ ‏.‏ قَالَ هَذَا حَدِيثٌ حَسَنٌ غَرِيبٌ ‏.‏ ‏\hadithno{1669}\hadithgrade{Ahmad Muhammad Shakir: Hasan; Al-Albani: Hasan; Bashar Awad Maarouf: Hasan; Zubair Ali Zai: Isnaad Hasan}\hadithtrans{Narrated Abu Umamah: That the Prophet (ﷺ) said: "There is nothing more beloved to Allah than two drops and two traces: A teardrop shed out of fear of Allah, and a drop of blood shed in Allah's cause. As for the two traces: A trace resulting in Allah's cause, and and a trace resulting from one of the duties that Allah made obligatory." [Abu 'Eisa said:] This Hadith is Hasan Gharib}}
